@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -25,7 +25,7 @@
  *  SUCH DAMAGE.
  *   
  *
- *  $Id: machine_evbmips.c,v 1.27 2007/06/15 18:08:10 debug Exp $
+ *  $Id: machine_evbmips.c,v 1.30.2.1 2008/01/18 19:12:33 debug Exp $
  *
  *  COMMENT: MIPS evaluation boards (e.g. Malta)
  */
@@ -55,6 +55,7 @@ MACHINE_SETUP(evbmips)
 	/*  See http://www.netbsd.org/ports/evbmips/ for more info.  */
 
 	switch (machine->machine_subtype) {
+
 	case MACHINE_EVBMIPS_MALTA:
 	case MACHINE_EVBMIPS_MALTA_BE:
 		if (machine->emulated_hz == 0)
@@ -140,13 +141,7 @@ MACHINE_SETUP(evbmips)
 	cpu->cd.mips.gpr[MIPS_GPR_A3] = machine->physical_ram_in_mb * 1048576;
 	/*  Hm. Linux ignores a3.  */
 
-	/*
-	 *  TODO:
-	 *	Core ID numbers.
-	 *	How much of this is not valid for PBxxxx?
-	 *
-	 *  See maltareg.h for more info.
-	 */
+	/*  Set the Core ID. See maltareg.h for more info.  */
 	store_32bit_word(cpu, (int32_t)(0x80000000 + MALTA_REVISION),
 	    (1 << 10) + 0x26);
 
@@ -180,7 +175,7 @@ MACHINE_DEFAULT_CPU(evbmips)
 
 MACHINE_DEFAULT_RAM(evbmips)
 {
-	machine->physical_ram_in_mb = 64;
+	machine->physical_ram_in_mb = 128;
 }
 
 
